@@ -6,7 +6,7 @@ def convert_formatted_enumerations_back_to_integer_values(enumeration, enum_valu
 
 def get_dict_key_from_value(source_dict, value_to_find):
     for key, value in source_dict.items():
-        if value_to_find == value:
+        if value_to_find.lower() == value.lower():
             return key
     raise Exception('Key: {}, not found in dict: {}'.format(value_to_find, source_dict)
 
